@@ -21,7 +21,7 @@ from tmuxp.types import StrPath
 from .. import config_reader, exc, log, util
 from ..workspace import loader
 from ..workspace.builder import WorkspaceBuilder
-from ..workspace.finders import find_workspace_file, get_workspace_dir, in_dir
+from ..workspace.finders import find_workspace_file, get_workspace_dir
 from .utils import prompt_choices, prompt_yes_no, style, tmuxp_echo
 
 if t.TYPE_CHECKING:
@@ -107,7 +107,7 @@ def set_layout_hook(session: Session, hook_name: str) -> None:
     session.cmd(*cmd)
 
 
-def load_plugins(sconf: t.Any) -> t.List[t.Any]:
+def load_plugins(sconf: t.Dict[str, t.Any]) -> t.List[t.Any]:
     """
     Load and return plugins in workspace
     """
@@ -158,6 +158,7 @@ def _reattach(builder: WorkspaceBuilder):
 
     If not, ``tmux attach-session`` loads the client to the target session.
     """
+    assert builder.session is not None
     for plugin in builder.plugins:
         plugin.reattach(builder.session)
         proc = builder.session.cmd("display-message", "-p", "'#S'")
@@ -181,6 +182,7 @@ def _load_attached(builder: WorkspaceBuilder, detached: bool) -> None:
     detached : bool
     """
     builder.build()
+    assert builder.session is not None
 
     if "TMUX" in os.environ:  # tmuxp ran from inside tmux
         # unset TMUX, save it, e.g. '/tmp/tmux-1000/default,30668,0'
@@ -214,6 +216,8 @@ def _load_detached(builder: WorkspaceBuilder) -> None:
     """
     builder.build()
 
+    assert builder.session is not None
+
     if has_gte_version("2.6"):  # prepare for both cases
         set_layout_hook(builder.session, "client-attached")
         set_layout_hook(builder.session, "client-session-changed")
@@ -231,6 +235,7 @@ def _load_append_windows_to_current_session(builder: WorkspaceBuilder) -> None:
     """
     current_attached_session = builder.find_current_attached_session()
     builder.build(current_attached_session, append=True)
+    assert builder.session is not None
     if has_gte_version("2.6"):  # prepare for both cases
         set_layout_hook(builder.session, "client-attached")
         set_layout_hook(builder.session, "client-session-changed")
@@ -244,6 +249,7 @@ def _setup_plugins(builder: WorkspaceBuilder) -> Session:
     ----------
     builder: :class:`workspace.builder.WorkspaceBuilder`
     """
+    assert builder.session is not None
     for plugin in builder.plugins:
         plugin.before_script(builder.session)
 
@@ -254,7 +260,7 @@ def load_workspace(
     workspace_file: StrPath,
     socket_name: t.Optional[str] = None,
     socket_path: None = None,
-    tmux_config_file: None = None,
+    tmux_config_file: t.Optional[str] = None,
     new_session_name: t.Optional[str] = None,
     colors: t.Optional[int] = None,
     detached: bool = False,
@@ -382,7 +388,7 @@ def load_workspace(
     t = Server(  # create tmux server object
         socket_name=socket_name,
         socket_path=socket_path,
-        workspace_file=tmux_config_file,
+        config_file=tmux_config_file,
         colors=colors,
     )
 
@@ -458,8 +464,9 @@ def load_workspace(
         )
 
         if choice == "k":
-            builder.session.kill_session()
-            tmuxp_echo("Session killed.")
+            if builder.session is not None:
+                builder.session.kill_session()
+                tmuxp_echo("Session killed.")
         elif choice == "a":
             _reattach(builder)
         else:
@@ -468,28 +475,6 @@ def load_workspace(
     return _setup_plugins(builder)
 
 
-def workspace_file_completion(ctx, params, incomplete):
-    workspace_dir = pathlib.Path(get_workspace_dir())
-    choices: t.List[pathlib.Path] = []
-
-    # CWD Paths
-    choices += sorted(
-        pathlib.Path(os.path.relpath(p, pathlib.Path.cwd()))
-        for p in [pathlib.Path.cwd(), *pathlib.Path.cwd().parents]
-        if in_dir(str(p)) or len(list(p.glob(".tmuxp.*")))
-    )
-    # CWD look one directory up
-    choices += [
-        pathlib.Path(f"./{os.path.relpath(p, pathlib.Path.cwd())}")
-        for p in pathlib.Path.cwd().glob("*/.tmuxp.*")
-    ]
-
-    # Project workspace
-    choices += sorted((workspace_dir / c).stem for c in in_dir(str(workspace_dir)))
-
-    return sorted(str(c) for c in choices if str(c).startswith(incomplete))
-
-
 def create_load_subparser(parser: argparse.ArgumentParser) -> argparse.ArgumentParser:
     workspace_files = parser.add_argument(
         "workspace_files",
